# msdss-models-api

[![pypi package](https://badge.fury.io/py/msdss-models-api.svg)](https://pypi.org/project/msdss-models-api)
[![Github](https://img.shields.io/badge/Github-rrwen%2Fmsdss--models--api-brightgreen?logo=Github)](https://github.com/rrwen/msdss-models-api)
[![downloads](https://img.shields.io/pypi/dm/msdss-models-api.svg)](https://pypistats.org/packages/msdss-models-api)
[![GitHub stars](https://img.shields.io/github/stars/rrwen/msdss-models-api.svg)](https://github.com/rrwen/msdss-models-api/stargazers)
[![GitHub](https://img.shields.io/github/license/rrwen/msdss-models-api.svg)](https://github.com/rrwen/msdss-models-api/blob/main/LICENSE)
  
Model management API for the Modular Spatial Decision Support Systems (MSDSS) framework.

* [Documentation](https://rrwen.github.io/msdss-models-api/)
* [Developer Notes](https://github.com/rrwen/msdss-models-api/blob/main/DEVELOPER.md)

## Contact

Richard Wen rrwen.dev@gmail.com
